Browser extension

Browser extension is a tool that makes it easy to integrate browser extensions into web automation frameworks like Botasaurus, Selenium, and Playwright.

With this tool, you can seamlessly download, configure, and use any Chrome extension.

This project is a fork of [chrome-extension-python](https://github.com/omkarcloud/chrome-extension-python).
